==> nextcloud-14.0.13.zip: nextcloud/apps/firstrunwizard/l10n/is.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Afrita á klippispjald",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "First run wizard" : "Fyrsta-skiptis-leiðarvísir",
    "Add your profile information! For example your email is needed to reset your password." : "Bættu við notandaupplýsingarnar þínar! Til dæmis þarftu að setja inn tölvupóstfangið þitt til að geta endurstillt lykilorð.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu auðkennismynd og fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn auðkennismynd svo auðveldara verði að nota marga eiginleika.",
    "About" : "Um hugbúnaðinn",
    "A welcome and introduction wizard for Nextcloud" : "Kynning og leiðarvísir fyrir Nextcloud",
    "Start using Nextcloud" : "Byrjaðu að nota Nextcloud",
    "Extend your cloud" : "Útvíkkaðu tölvuskýið þitt",
    "Find more than 100 apps in the Nextcloud app store to customize your cloud:" : "Skoðaðu meira en 100 forrit í forritasafni Nextcloud til að sérsníða tölvuskýið þitt:",
    "Groupware apps like Calendar, Contacts, Mail" : "Hópvinnuforrit á borð við Dagbók, Tengiliðir, Póstur",
    "Communication with Nextcloud Talk" : "Samskipti með Nextcloud Talk",
    "Collaboration apps for document editing" : "Samstarfsforrit til vinnslu skjala",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Öryggis- og auðkenningareiginleikar á borð við tveggja-þrepa-sannvottun, varnir gegn SSO og fjárkúgunaróværu",
    "Many others like a music player, a password manager, a kanban app, a download manager or a markdown editor" : "Margt fleira eins og tónlistarspilari, lykilorðastjóri, kanban-forrit, niðurhalsstjóri eða ritill fyrir markdown-kóða",
    "Browse the app store" : "Flakka um forritasafnið",
    "Stay in sync" : "Vertu samstilltur",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud gefur þér aðgang að skránum þínum hvar sem þú ert.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar!",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "Desktop client" : "Skjáborðsforrit",
    "Android app" : "Android-forrit",
    "iOS app" : "iOS-forrit",
    "Connect your desktop apps to %s" : "Tengdu skjáborðsforritin við %s",
    "Connect your calendar" : "Tengdu dagatalið þitt",
    "Connect your contacts" : "Tengdu tengiliðalistana þína",
    "Access files via WebDAV" : "Nálgastu skrár í gegnum WebDAV",
    "Download macOS/iOS configuration profile" : "Sækja macOS/iOS uppsetningasnið",
    "Get help" : "Til að fá hjálp",
    "Get more information" : "Til að fá frekari upplýsingar",
    "The Nextcloud documentation for home users:" : "Nextcloud hjálparskjöl fyrir heimanotendur",
    "User manual" : "Notendahandbók",
    "Admin manual" : "Handbók kerfisstjóra",
    "Developer manual" : "Handbók forritara",
    "You can also ask for help in our community support channels:" : "Þú getur einnig beðið um aðstoð á stuðningsmiðlum samfélagsins okkar:",
    "the Nextcloud forums" : "vefspjallsíðum Nextcloud",
    "the Nextcloud IRC chat channel on freenode.net" : "IRC-spjallrás Nextcloud á freenode.net",
    "Start contributing" : "Byrjaðu að gefa af þér",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Viltu ná fram einhverjum ákveðnum endurbótum á Nextcloud? Fannstu vandamál? Viltu hjálpa til við að þýða, kynna eða skrifa um Nextcloud?",
    "Become part of the Community" : "Gakktu til liðs við samfélagið",
    "Enterprise support" : "Stuðningur við fyrirtæki",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Ef þú ert að keyra Nextcloud í krefjandi umhverfi (mission critical environment) með miklum fjölda notenda og miklu magni gagna - og þarft að vera viss um að geta fengið aðstoð frá sérfræðingum sem séu með púlsinn á tækninni á bak við Nextcloud, þá er í boði fyrirtækjaáskrift (Enterprise Subscription) frá Nextcloud sem felur í sér aðstoð í gegnum síma og tölvupóst.",
    "Get enterprise support" : "Fáðu stuðning við fyrirtæki",
    "A safe home for all your data" : "Öruggur staður fyrir öll gögnin þín",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud setur gögnin þín í þínar hendur, undir þína stjórn. Geymdu skjölin þín, dagatal, tengiliði og myndir á vefþjón í fyrirtækinu þínu, heima hjá þér, hjá einhverjum þjónustuaðila sem við mælum með eða í gagnaveri sem þú treystir.",
    "Host your data and files where you decide" : "Hýstu gögn þín og skrár þar sem þú ákveður",
    "Open Standards and Interoperability" : "Opnir staðlar og samstarfshæfni",
    "100%% Open Source & community-focused" : "100%% opinn hugbúnaður (open source) með áherslu á samfélagið",
    "Learn more about %s" : "Vita meira um %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s veitir þér aðgang að skránum þínum hvar sem þú ert. Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar.",
    "Setup sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Settu upp samstillingarbiðlara með <a href=\"%s\">lykilorði forrits</a>. Þannig geturðu verið viss um að geta afturkallað aðgangsheimildir fari svo að þú tapir því tæki.",
    "Connect other apps to %s" : "Tengdu önnur forrit við %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Fyrir utan samstillingaforritin geturðu tengt hvert það forrit sem styður WebDAV/CalDAV/CardDAV samskiptamátana við %s.",
    "Server address" : "Vistfang þjóns",
    "Use this URL to connect your clients to this server:" : "Notaðu þessa slóð fyrir forritin þín til að tengjast þessum þjóni:",
    "Previous" : "Fyrra",
    "Next" : "Næsta"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-25.0.0rc3.zip: nextcloud/apps/firstrunwizard/l10n/is.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "Copy to clipboard" : "Afrita á klippispjald",
    "Copied!" : "Afritað!",
    "Not supported!" : "Ekki stutt!",
    "Press ⌘-C to copy." : "Ýttu á ⌘-C til að afrita.",
    "Press Ctrl-C to copy." : "Ýttu á Ctrl-C til að afrita.",
    "First run wizard" : "Fyrsta-skiptis-leiðarvísir",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu auðkennismynd og fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn fullt nafn svo auðveldara verði að nota marga eiginleika.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Bættu við notandaupplýsingarnar þínar! Settu inn auðkennismynd svo auðveldara verði að nota marga eiginleika.",
    "App recommendation: Nextcloud Calendar" : "Forrit sem mælt er með: Nextcloud Calendar dagatalsforrit",
    "Schedule work & meetings, synced with all your devices." : "Áætlun vinnu og stefnumóta, samstillt við öll tækin þín.",
    "App recommendation: Nextcloud Contacts" : "Forrit sem mælt er með: Nextcloud Contacts tengiliðaforrit",
    "Keep your colleagues and friends in one place without leaking their private info." : "Hafðu samstarfsfólk og vini á einum stað án þess að leka einkaupplýsingum þeirra.",
    "App recommendation: Nextcloud Mail" : "Forrit sem mælt er með: Nextcloud Mail póstforrit",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Einfalt og stílhreint tölvupóstforrit sem virkar með skráaforritinu, tengiliðum og dagatalinu.",
    "App recommendation: Tasks" : "Forrit sem mælt er með: Tasks verkefnaforrit",
    "App recommendation: Deck" : "Forrit sem mælt er með: Deck spjaldaforrit",
    "Kanban style organization for personal planning and team projects." : "Persónuleg áætlanagerð og skipulag verkefnisvinnu í Kanban-stíl.",
    "App recommendation: Group folders" : "Forrit sem mælt er með: Möppur hóps",
    "Admin-configured folders shared by everyone in a group." : "Möppur settar upp af kerfisstjóra sem deilt með öllum í hópi.",
    "About" : "Um hugbúnaðinn",
    "A welcome and introduction wizard for Nextcloud" : "Kynning og leiðarvísir fyrir Nextcloud",
    "Extend your cloud" : "Útvíkkaðu tölvuskýið þitt",
    "Groupware apps like Calendar, Contacts, Mail" : "Hópvinnuforrit á borð við Dagbók, Tengiliðir, Póstur",
    "Communication with Nextcloud Talk" : "Samskipti með Nextcloud Talk",
    "Collaboration apps for document editing" : "Samstarfsforrit til vinnslu skjala",
    "Security and authentication features like two-factor authentication, SSO and ransomware protection" : "Öryggis- og auðkenningareiginleikar á borð við tveggja-þrepa-sannvottun, varnir gegn SSO og fjárkúgunaróværu",
    "Many others like a music player, a password manager, a kanban app, a download manager or a Markdown editor" : "Margt fleira eins og tónlistarspilari, lykilorðastjóri, kanban-forrit, niðurhalsstjóri eða ritill fyrir markdown-kóða",
    "Stay in sync" : "Vertu samstilltur",
    "Nextcloud gives you access to your files wherever you are." : "Nextcloud gefur þér aðgang að skránum þínum hvar sem þú ert.",
    "Our easy to use desktop and mobile clients are available for all major platforms at zero cost!" : "Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar!",
    "Get the apps to sync your files" : "Náðu í forrit til að samstilla skrárnar þínar",
    "Desktop client" : "Skjáborðsforrit",
    "iOS app" : "iOS-forrit",
    "Connect your desktop apps to %s" : "Tengdu skjáborðsforritin við %s",
    "Connect your calendar" : "Tengdu dagatalið þitt",
    "Connect your contacts" : "Tengdu tengiliðalistana þína",
    "Access files via WebDAV" : "Nálgastu skrár í gegnum WebDAV",
    "Download macOS/iOS configuration profile" : "Sækja macOS/iOS uppsetningasnið",
    "Get help" : "Til að fá hjálp",
    "Start contributing" : "Byrjaðu að gefa af þér",
    "Do you want to get a certain improvement in Nextcloud? Did you find a problem? Do you want to help translate, promote or document Nextcloud?" : "Viltu ná fram einhverjum ákveðnum endurbótum á Nextcloud? Fannstu vandamál? Viltu hjálpa til við að þýða, kynna eða skrifa um Nextcloud?",
    "Become part of the Community" : "Gakktu til liðs við samfélagið",
    "Enterprise support" : "Stuðningur við fyrirtæki",
    "Get more information" : "Til að fá frekari upplýsingar",
    "The Nextcloud documentation for home users:" : "Nextcloud hjálparskjöl fyrir heimanotendur",
    "User manual" : "Notendahandbók",
    "Admin manual" : "Handbók kerfisstjóra",
    "Developer manual" : "Handbók forritara",
    "You can also ask for help in our community support channels:" : "Þú getur einnig beðið um aðstoð á stuðningsmiðlum samfélagsins okkar:",
    "the Nextcloud forums" : "vefspjallsíðum Nextcloud",
    "A safe home for all your data" : "Öruggur staður fyrir öll gögnin þín",
    "Nextcloud puts your data at your fingertips, under your control. Store your documents, calendar, contacts and photos on a server in your company, at home, at one of our providers or in a data center you know." : "Nextcloud setur gögnin þín í þínar hendur, undir þína stjórn. Geymdu skjölin þín, dagatal, tengiliði og myndir á vefþjón í fyrirtækinu þínu, heima hjá þér, hjá einhverjum þjónustuaðila sem við mælum með eða í gagnaveri sem þú treystir.",
    "Host your data and files where you decide" : "Hýstu gögn þín og skrár þar sem þú ákveður",
    "Learn more about %s" : "Vita meira um %s",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s veitir þér aðgang að skránum þínum hvar sem þú ert. Tengiforritin okkar fyrir tölvur og snjalltæki eru fáanleg fyrir flest algengustu stýrikerfi án nokkurs kostnaðar.",
    "Set up sync clients using an <a href=\"%s\">app password</a>. That way you can make sure you are able to revoke access in case you lose that device." : "Settu upp samstillingarbiðlara með <a href=\"%s\">lykilorði forrits</a>. Þannig geturðu verið viss um að geta afturkallað aðgangsheimildir fari svo að þú tapir því tæki.",
    "Connect other apps to %s" : "Tengdu önnur forrit við %s",
    "Besides the mobile apps and desktop client you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Fyrir utan samstillingaforritin fyrir snjalltæki og vinnutölvur geturðu tengt hvert það forrit sem styður WebDAV/CalDAV/CardDAV samskiptamátana við %s.",
    "Server address" : "Vistfang þjóns",
    "Use this link to connect your apps and desktop client to this server:" : "Notaðu þessa slóð fyrir forritin þín til að tengjast þessum þjóni:",
    "Copy link" : "Afrita tengil",
    "App recommendation: Notes" : "Forrit sem mælt er með: Notes minnispunktaforrit",
    "Distraction-free notes and writing." : "Augljós ritun og skoðun minnispunkta.",
    "Android app" : "Android-forrit",
    "If you run Nextcloud in a mission critical environment with large numbers of users and big amounts of data and need the certainty of support from the experts behind the Nextcloud technology, an Enterprise Subscription from Nextcloud is available with email and phone support." : "Ef þú ert að keyra Nextcloud í krefjandi umhverfi (mission critical environment) með miklum fjölda notenda og miklu magni gagna - og þarft að vera viss um að geta fengið aðstoð frá sérfræðingum sem séu með púlsinn á tækninni á bak við Nextcloud, þá er í boði fyrirtækjaáskrift (Enterprise Subscription) frá Nextcloud sem felur í sér aðstoð í gegnum síma og tölvupóst.",
    "Get enterprise support" : "Fáðu stuðning við fyrirtæki",
    "the Nextcloud IRC chat channel on freenode.net" : "IRC-spjallrás Nextcloud á freenode.net",
    "Open Standards and Interoperability" : "Opnir staðlar og samstarfshæfni",
    "100%% Open Source & community-focused" : "100%% opinn hugbúnaður (open source) með áherslu á samfélagið"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
